@@ -1,41 +1,47 @@
 #!/usr/bin/python3
 #
-# The Qubes OS Project, http://www.qubes-os.org
+# The Qubes OS Project, https://www.qubes-os.org/
 #
 # Copyright (C) 2012  Agnieszka Kostrzewa <agnieszka.kostrzewa@gmail.com>
 # Copyright (C) 2012  Marek Marczykowski <marmarek@mimuw.edu.pl>
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public License along
-# with this program; if not, see <http://www.gnu.org/licenses/>.
-#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 import signal
 from qubesadmin import exc
 from qubesadmin import utils as admin_utils
+from qubesadmin.backup.restore \
+    import KNOWN_COMPRESSION_FILTERS, OPTIONAL_COMPRESSION_FILTERS
 
-from PyQt5 import QtCore, QtWidgets, QtGui, Qt  # pylint: disable=import-error
-from . import ui_backupdlg  # pylint: disable=no-name-in-module
-from . import multiselectwidget
+from PyQt6 import QtCore, QtWidgets, QtGui  # pylint: disable=import-error
+from qubesmanager import ui_backupdlg  # pylint: disable=no-name-in-module
+from qubesmanager import multiselectwidget
 
-from . import backup_utils
-from . import utils
+from qubesmanager import backup_utils
+from qubesmanager import utils
 
 import grp
 import pwd
 import os
 import shutil
 
+# this is needed for icons to actually work
+# pylint: disable=unused-import, no-name-in-module
+from . import resources
+
 # pylint: disable=too-few-public-methods
 class BackupThread(QtCore.QThread):
     def __init__(self, vm):
@@ -81,8 +87,8 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
         self.setupUi(self)
 
         self.setWindowFlags(self.windowFlags() |
-                            Qt.Qt.WindowMaximizeButtonHint |
-                            Qt.Qt.WindowMinimizeButtonHint)
+                            QtCore.Qt.WindowType.WindowMaximizeButtonHint |
+                            QtCore.Qt.WindowType.WindowMinimizeButtonHint)
 
         self.progress_status.text = self.tr("Backup in progress...")
         self.dir_line_edit.setReadOnly(False)
@@ -125,6 +131,13 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
             self.appvm_combobox.findText("dom0"))
 
         self.unrecognized_config_label.setVisible(False)
+
+        self.compression_combobox.addItem("Default (gzip)")
+        self.compression_combobox.addItems(KNOWN_COMPRESSION_FILTERS)
+        self.compression_combobox.addItems(
+            [c for c in OPTIONAL_COMPRESSION_FILTERS if shutil.which(c)]
+        )
+        self.compression_combobox.addItem("Disabled (uncompressed)")
         self.load_settings()
 
         self.show_passwd_button.pressed.connect(self.show_hide_password)
@@ -146,11 +159,13 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
 
     def show_hide_password(self):
         if self.show_passwd_button.isChecked():
-            self.passphrase_line_edit.setEchoMode(QtWidgets.QLineEdit.Password)
-            self.show_passwd_button.setIcon(QtGui.QIcon(':/eye-off.svg'))
+            self.passphrase_line_edit.setEchoMode(
+                QtWidgets.QLineEdit.EchoMode.Password)
+            self.show_passwd_button.setIcon(QtGui.QIcon(':/eye-off'))
         else:
-            self.passphrase_line_edit.setEchoMode(QtWidgets.QLineEdit.Normal)
-            self.show_passwd_button.setIcon(QtGui.QIcon(':/eye.svg'))
+            self.passphrase_line_edit.setEchoMode(
+                QtWidgets.QLineEdit.EchoMode.Normal)
+            self.show_passwd_button.setIcon(QtGui.QIcon(':/eye'))
 
     def save_profile_changed(self):
         save_profile = self.save_profile_checkbox.isChecked()
@@ -165,6 +180,7 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
     def setup_application(self):
         self.qt_app.setApplicationName(self.tr("Qubes Backup VMs"))
         self.qt_app.setWindowIcon(QtGui.QIcon.fromTheme("qubes-manager"))
+        self.qt_app.setDesktopFileName("qubes-backup")
 
     def on_backup_progress(self, __submitter, _event, **kwargs):
         self.progress_bar.setValue(int(float(kwargs['progress'])))
@@ -195,6 +211,9 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
         try:
             profile_data = backup_utils.load_backup_profile()
         except FileNotFoundError:
+            dest_vm_idx = self.appvm_combobox.findText("sys-usb")
+            if dest_vm_idx > -1:
+                self.appvm_combobox.setCurrentIndex(dest_vm_idx)
             return
         except exc.QubesException:
             QtWidgets.QMessageBox.information(
@@ -228,7 +247,21 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
             self.save_passphrase_checkbox.setChecked(False)
 
         if 'compression' in profile_data:
-            self.compress_checkbox.setChecked(profile_data['compression'])
+            if isinstance(profile_data["compression"], bool):
+                if profile_data["compression"]:
+                    # Technically this is necessary as the default index is -1
+                    self.compression_combobox.setCurrentIndex(0)
+                else:
+                    self.compression_combobox.setCurrentIndex(
+                        self.compression_combobox.count() - 1
+                    )
+            else:
+                for i in range(self.compression_combobox.count()):
+                    if profile_data[
+                        "compression"
+                    ] == self.compression_combobox.itemText(i):
+                        self.compression_combobox.setCurrentIndex(i)
+                        break
 
     def save_settings(self, use_temp, save_passphrase=True):
         """
@@ -238,10 +271,20 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
         :param use_temp: whether to use temporary profile (True) or the default
          backup profile (False)
         """
-        settings = {'destination_vm': self.appvm_combobox.currentText(),
-                    'destination_path': self.dir_line_edit.text(),
-                    'include': [vm.name for vm in self.selected_vms],
-                    'compression': self.compress_checkbox.isChecked()}
+        if self.compression_combobox.currentIndex() != -1:
+            compression_filter = self.compression_combobox.currentText()
+            if compression_filter.startswith("Default"):
+                compression_filter = True
+            elif compression_filter.startswith("Disabled"):
+                compression_filter = False
+        else:
+            compression_filter = True
+        settings = {
+            "destination_vm": self.appvm_combobox.currentText(),
+            "destination_path": self.dir_line_edit.text(),
+            "include": [vm.name for vm in self.selected_vms],
+            "compression": compression_filter
+        }
 
         if save_passphrase:
             settings['passphrase_text'] = self.passphrase_line_edit.text()
@@ -280,6 +323,7 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
                 continue
 
             item = BackupVMsWindow.VmListItem(vm)
+            item.setIcon(QtGui.QIcon.fromTheme(vm.icon))
             if (selected is None and
                     getattr(vm, 'include_in_backups', True)) \
                     or (selected and vm.name in selected):
@@ -367,6 +411,8 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
             except exc.QubesDaemonAccessError:
                 backup_summary = "Failed to get backup summary: " \
                                  "insufficient permissions"
+            except exc.QubesException as e:
+                backup_summary = str(e)
 
             self.textEdit.setReadOnly(True)
             self.textEdit.setFontFamily("Monospace")
@@ -379,7 +425,7 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
                 self.save_settings(use_temp=False,
                    save_passphrase=save_passphrase)
 
-            self.button(self.FinishButton).setDisabled(True)
+            self.button(self.WizardButton.FinishButton).setDisabled(True)
             self.showFileDialog.setEnabled(
                 self.appvm_combobox.currentIndex() != 0)
             self.showFileDialog.setChecked(self.showFileDialog.isEnabled()
@@ -402,8 +448,8 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
                 self, self.tr("Backup error"),
                 self.tr("ERROR: {}").format(
                     self.thread.msg))
-            self.button(self.CancelButton).setEnabled(False)
-            self.button(self.FinishButton).setEnabled(True)
+            self.button(self.WizardButton.CancelButton).setEnabled(False)
+            self.button(self.WizardButton.FinishButton).setEnabled(True)
             self.cleanup_temporary_files()
 
         else:
@@ -418,8 +464,8 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
                         "the file selection dialog."))
                 backup_utils.select_path_button_clicked(self, False, True)
 
-            self.button(self.CancelButton).setEnabled(False)
-            self.button(self.FinishButton).setEnabled(True)
+            self.button(self.WizardButton.CancelButton).setEnabled(False)
+            self.button(self.WizardButton.FinishButton).setEnabled(True)
             self.showFileDialog.setEnabled(False)
             self.cleanup_temporary_files()
 
@@ -429,7 +475,7 @@ class BackupVMsWindow(ui_backupdlg.Ui_Backup, QtWidgets.QWizard):
 
     def reject(self):
         if (self.currentPage() is self.commit_page) and \
-                self.button(self.CancelButton).isEnabled():
+                self.button(self.WizardButton.CancelButton).isEnabled():
             try:
                 self.qubes_app.qubesd_call(
                     'dom0', 'admin.backup.Cancel',
